-----------------------------------------------------------------------------

local L = AceLibrary("AceLocale-2.2"):new("AloftIsPetData")
local roster = AceLibrary("Roster-2.1")

-----------------------------------------------------------------------------

local petNames = { }

-----------------------------------------------------------------------------

local AloftIsPetData = Aloft:NewModule("IsPetData", "AceEvent-2.0")
AloftIsPetData.db = Aloft:AcquireDBNamespace("isPetData")
Aloft:RegisterDefaults("isPetData", "server", {
	petNames = { }
})

-----------------------------------------------------------------------------

function AloftIsPetData:ProvidesData()
	return "isPet"
end

function AloftIsPetData:EnableDataSource()
	-- Events to update our class database
    self:RegisterEvent("UPDATE_MOUSEOVER_UNIT", "UpdatePetFromMouseOver")
    self:RegisterEvent("PLAYER_TARGET_CHANGED", "UpdatePetFromTarget")
end

-----------------------------------------------------------------------------

function AloftIsPetData:OnEnable()
	petNames = self.db.server.petNames
end

-----------------------------------------------------------------------------

function AloftIsPetData:UpdateData(aloftData)
	aloftData.isPet = nil
	
	-- This is so that pets named the same as players we've encountered aren't given a class incorrectly
	if aloftData.type == "friendlyNPC" or aloftData.type == "hostile" then
		aloftData.isPet = petNames[aloftData.name]
	end
end

-----------------------------------------------------------------------------

function AloftIsPetData:SetPet(name)
	if not name or petNames[name] then return end
	petNames[name] = true
	
	local frame = Aloft:GetNameplateFrame(name)
	if frame then
		local aloftData = frame.aloftData
		if not aloftData.isPet and (aloftData.type == "friendlyNPC" or aloftData.type == "hostile") then
			Aloft:UpdateData(aloftData)
			self:TriggerEvent("Aloft:OnIsPetDataChanged", frame)
		end
	end
end

-----------------------------------------------------------------------------

local function IsPet(unitid)
	return UnitExists(unitid) and not UnitIsPlayer(unitid) and UnitPlayerControlled(unitid)
end

function AloftIsPetData:UpdatePetFromMouseOver()
	if IsPet("mouseover") then
		self:SetPet(UnitName("mouseover"))
	end
end

function AloftIsPetData:UpdatePetFromTarget()
	if IsPet("target") then
		self:SetPet(UnitName("target"))
	end
end

-----------------------------------------------------------------------------
